@@ -12,7 +12,7 @@ use IO::Socket::IP -register;
 use IO::Socket::SSL;
 use Time::Crontab;
 
-our $VERSION = '1.39'; # VERSION
+our $VERSION = '1.40'; # VERSION
 
 sub new {
     my $class = shift;
@@ -74,7 +74,7 @@ sub run {
         try {
             binmode( $self->{socket}, "encoding($self->{encoding})" );
         }
-        catch {};
+        catch ($e) {}
     }
 
     if ( $self->{send_user_nick} eq 'on_connect' ) {
@@ -96,10 +96,9 @@ sub run {
             },
         );
     }
-    catch {
-        my $e = $_ || $@;
+    catch ($e) {
         croak("Daemon device instantiation failure: $e");
-    };
+    }
 
     $self->{device}->run;
 }
@@ -151,10 +150,9 @@ sub _parent {
             try {
                 $_->{code}->($self);
             }
-            catch {
-                my $e = $_ || $@;
+            catch ($e) {
                 warn "Tick execution failure: $e\n";
-            };
+            }
         }
     };
 
@@ -234,10 +232,9 @@ sub _parent {
             push @lines, { line => $line, time => $now };
         }
     }
-    catch {
-        my $e = $_ || $@;
+    catch ($e) {
         warn "Daemon parent loop failure: $e\n";
-    };
+    }
 
     kill( 'KILL', $_ ) for ( @{ $device->children } );
     $self->{disconnect}->($self) if ( ref $self->{disconnect} eq 'CODE' );
@@ -432,10 +429,9 @@ sub _on_message {
                     $captured_matches,
                 );
             }
-            catch {
-                my $e = $_ || $@;
+            catch ($e) {
                 warn "Plugin hook execution failure: $e\n";
-            };
+            }
 
             last if ($rv);
         }
@@ -538,9 +534,9 @@ sub helps {
     try {
         $self->{helps} = { %{ $self->{helps} }, @input };
     }
-    catch {
+    catch ($e) {
         $self->note('Plugin helps called but not properly implemented');
-    };
+    }
 
     return $self;
 }
@@ -717,7 +713,7 @@ Bot::IRC - Yet Another IRC Bot
 
 =head1 VERSION
 
-version 1.39
+version 1.40
 
 =for markdown [![test](https://github.com/gryphonshafer/Bot-IRC/workflows/test/badge.svg)](https://github.com/gryphonshafer/Bot-IRC/actions?query=workflow%3Atest)
 [![codecov](https://codecov.io/gh/gryphonshafer/Bot-IRC/graph/badge.svg)](https://codecov.io/gh/gryphonshafer/Bot-IRC)
